==> Brundle_1.0.5.tar.gz: Brundle/R/brundle-data.R <==
#' @name jg.controlPeaks
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.controlPeaks
#' @format a matrix of locations and counts per experimental sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name dbaExperiment
#' @title Example DiffBind Object
#' @description This data set is a DiffBind object of example ChIP-seq experiments
#' @docType data
#' @usage jdbaExperiment
#' @format Diffbind Object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.conditions
#' @title Example Sample Condition Matrix
#' @description This data set is a list of example conditions
#' @docType data
#' @usage jg.conditions
#' @format list
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlCountsTreated
#' @title Example ChIP-seq Count Matrix
#' @description This data set is a list counts from an Example ChIP-seq experiment
#' @docType data
#' @usage jg.controlCountsTreated
#' @format matrix
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlCountsUntreated
#' @title Example ChIP-seq Count Matrix
#' @description This data set is a list counts from an Example ChIP-seq experiment
#' @docType data
#' @usage jg.controlCountsUntreated
#' @format matrix
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlPeakset
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example control peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.controlPeakset
#' @format a matrix of locations and counts per control sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlPeaksetDeSeq
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example control peaks for normalisation of ChIP-seq data formatted for DeSEQ2
#' @docType data
#' @usage jg.controlPeaksetDeSeq
#' @format a matrix of locations and counts  sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlResultsDeseq
#' @title Example ChIP-seq DeSEQ2 Control results
#' @description This data set is a GRanges object of example control results from DeSEQ2
#' @docType data
#' @usage jg.controlResultsDeseq
#' @format DeSEQ2 results object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.experimentPeakset
#' @title Example ChIP-seq Experiment Peakset
#' @description This data set is a matrix of example peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.experimentPeakset
#' @format a matrix of locations and counts per control sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.experimentResultsDeseq
#' @title Example ChIP-seq DeSEQ2 results
#' @description This data set is a GRanges object of example results from DeSEQ2
#' @docType data
#' @usage jg.experimentResultsDeseq
#' @format DeSEQ2 results object
#' @source Original data from experiment
#' @author Andrew Holding
NULL

==> Brundle_1.0.8.tar.gz: Brundle/R/brundle-data.R <==
#' @name jg.controlPeaks
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.controlPeaks
#' @format a matrix of locations and counts per experimental sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name dbaExperiment
#' @title Example DiffBind Object of Experimental Peaks
#' @description This data set is a DiffBind object of example ChIP-seq experiments
#' @docType data
#' @usage jdbaExperiment
#' @format Diffbind Object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name dbaControl
#' @title Example DiffBind Object of Control Peaks
#' @description This data set is a DiffBind object of example ChIP-seq experiments
#' @docType data
#' @usage jdbaExperiment
#' @format Diffbind Object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.conditions
#' @title Example Sample Condition Matrix
#' @description This data set is a list of example conditions
#' @docType data
#' @usage jg.conditions
#' @format list
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlCountsTreated
#' @title Example ChIP-seq Count Matrix
#' @description This data set is a list counts from an Example ChIP-seq experiment
#' @docType data
#' @usage jg.controlCountsTreated
#' @format matrix
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlCountsUntreated
#' @title Example ChIP-seq Count Matrix
#' @description This data set is a list counts from an Example ChIP-seq experiment
#' @docType data
#' @usage jg.controlCountsUntreated
#' @format matrix
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlPeakset
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example control peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.controlPeakset
#' @format a matrix of locations and counts per control sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlPeaksetDeSeq
#' @title Example ChIP-seq Control Peakset
#' @description This data set is a matrix of example control peaks for normalisation of ChIP-seq data formatted for DeSEQ2
#' @docType data
#' @usage jg.controlPeaksetDeSeq
#' @format a matrix of locations and counts  sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.controlResultsDeseq
#' @title Example ChIP-seq DeSEQ2 Control results
#' @description This data set is a GRanges object of example control results from DeSEQ2
#' @docType data
#' @usage jg.controlResultsDeseq
#' @format DeSEQ2 results object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.experimentPeakset
#' @title Example ChIP-seq Experiment Peakset
#' @description This data set is a matrix of example peaks for normalisation of ChIP-seq data
#' @docType data
#' @usage jg.experimentPeakset
#' @format a matrix of locations and counts per control sample
#' @source Original data from experiment
#' @author Andrew Holding
NULL
#' @name jg.experimentResultsDeseq
#' @title Example ChIP-seq DeSEQ2 results
#' @description This data set is a GRanges object of example results from DeSEQ2
#' @docType data
#' @usage jg.experimentResultsDeseq
#' @format DeSEQ2 results object
#' @source Original data from experiment
#' @author Andrew Holding
NULL
